
Init/Apply
==============

.. currentmodule:: flax.linen

.. autofunction:: apply
.. autofunction:: init
.. autofunction:: init_with_output


**Summary**

.. autosummary::
  :toctree: _autosummary

  apply
  init
  init_with_output